@@ -25,6 +25,9 @@ plot(split(bramblecanes))
 
 plot(bronzefilter,markscale=2)
 
+plot(subset(btb, select=spoligotype), cols=2:5,
+     main="Bovine Tuberculosis, by spoligotype")
+
 plot(cells)
 
 plot(chicago, main="Chicago Street Crimes", col="grey",
@@ -37,6 +40,8 @@ plot(clmfires, which.marks="cause", cols=2:5, cex=0.25,
      main="Castilla-La Mancha forest fires")
 plot(clmfires.extra$clmcov200, main="Covariates for forest fires")
 
+plot(concrete)
+
 plot(copper$Points, main="Copper")
 plot(copper$Lines, add=TRUE)
 
@@ -125,6 +130,10 @@ text(15,8,"Tree", cex=0.75)
 
 plot(spruces, maxsize=min(nndist(spruces)))
 
+plot(subset(stonetools, select=TYPE),
+     main="Palaeolithic stone tools and bone fragments",
+     cols=2:3, cex=0.5)
+
 plot(swedishpines)
 
 plot(urkiola, cex=0.5, cols=2:3)
